Releases: openconfig/ygnmi
Releases · openconfig/ygnmi
v0.11.1
v0.11.0
Breaking Changes
- Names within
RequestValues
were changed to be clearer:
diff --git a/ygnmi/context.go b/ygnmi/context.go
index 6650736..bc668fd 100644
--- a/ygnmi/context.go
+++ b/ygnmi/context.go
@@ -20,35 +20,26 @@ import (
// RequestValues contains request-scoped values for ygnmi queries.
type RequestValues struct {
- // CompressedConfigQuery is a key type that means that the query is
- // uninterested in /state paths.
- CompressedConfigQuery bool
- // CompressedStateQuery is a key type that means that the query is
- // uninterested in /config paths.
- CompressedStateQuery bool
+ // StateFiltered is a key type that means that the query is
+ // uninterested in /state paths and will filter them out.
+ StateFiltered bool
+ // ConfigFiltered is a key type that means that the query is
+ // uninterested in /config paths and will filter them out.
+ ConfigFiltered bool
}
What's Changed
Full Changelog: v0.10.2...v0.11.0
v0.10.2
v0.10.1
v0.10.0
Breaking Changes
- Add hidden -typedef_enum_with_defmod flag by @wenovus in #119
- All current users are likely to experience a breaking change due to the addition of the hidden flag
-typedef_enum_with_defmod
which is by default "true". If this broke your code, you can either 1) set this flag to false, or 2) convert existing code to the supported enumeration names, which is named using the defining module of each enum. - NOTE: This flag is planned to be removed by ygnmi@v1.0.0
- All current users are likely to experience a breaking change due to the addition of the hidden flag
What's Changed
Full Changelog: v0.9.0...v0.10.0
v0.9.0
Breaking Changes
ygnmi.Batch.AddPaths
now takes in query types rather than PathStruct types. Fixing this generally involves removing the.PathStruct()
method call, or adding the.Config()
or.State()
method calls in the path call chain.
What's Changed
- Support Wildcard Batch by @wenovus in #133
- Use new UntypedQuery for Batch.AddPaths by @wenovus in #134
Full Changelog: v0.8.11...v0.9.0
v0.8.11
What's Changed
- Bump golang.org/x/net from 0.10.0 to 0.17.0 by @dependabot in #131
- Support batch on map root by @wenovus in #132
Full Changelog: v0.8.10...v0.8.11